@@ -1,8 +1,7 @@
-
-__all__ = ['Cache']
-
 from skyext.db.redis_db import Redis
 
+__all__ = ('Cache',)
+
 
 class Cache(object):
     def __int__(self):
