@@ -1,8 +1,7 @@
-
-__all__ = ['Session']
-
 from skyext.db.redis_db import Redis
 
+__all__ = ('Session',)
+
 
 class Session(object):
     def __int__(self):
